import re
import os

def isEmailValid(email):
    regex = re.compile(r'([A-Za-z0-9]+[.-_])*[A-Za-z0-9]+@[A-Za-z0-9-]+(\.[A-Z|a-z]{2,})+')
            
    return True if re.fullmatch(regex, email) else False
    
def domainToUrl(domain):
    url = domain.split('.')
    url[0] += '.txt'
    url.reverse()
    url = '/'.join(url)
    
    return url

def isAcademic(email):
    this_dir = os.path.split(__file__)[0]
    DATA_PATH = os.path.join(this_dir, "domains/")
    domain = email.split('@')[-1]
    url = domainToUrl(domain)
    path = DATA_PATH + url
    return os.path.exists(path)



from distutils.core import setup
setup(
  name = 'AcademicEmailVerifier',
  packages = ['AcademicEmailVerifier'],
  include_package_data=True,
  package_data = {'': ['domains/*.txt','domains/*/*.txt','domains/*/*/*.txt','domains/*/*/*/*.txt']},
  version = '1.1',
  license='MIT',
  description = 'Identifies email addresses or domains names that belong to colleges or universities.',
  author = 'Yervand Galoyan',
  author_email = 'yervandgaloyan26@gmail.com',
  url = 'https://github.com/yervandgaloyan/AcademicEmailVerifier/',
  download_url = 'https://github.com/yervandgaloyan/AcademicEmailVerifier/archive/refs/tags/v_10.tar.gz',
  keywords = ['EMAIL', 'ACADEMIC', 'VERIFIER'],
  classifiers=[
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
  ],
)